@@ -144,7 +144,10 @@ class HostedBackend(Backend):
         # api-token登录
         try:
             od = json.loads(base64.b64decode(api_token).decode('utf-8'))
-            os.environ.update({envs.API_URL: od['api_url']})
+            if os.environ.get(envs.API_URL):
+                pass
+            else:
+                os.environ.update({envs.API_URL: od['api_url']})
         except Exception:
             raise InvalidAPIToken()
         res = self._session.post(
@@ -368,14 +371,15 @@ class HostedBackend(Backend):
         url, destination, filename = urls
         destination_loc = os.path.join(destination, filename)
         content_size = 0
-        headers_types = ['application/octet-stream', 'application/zip', 'image/png', 'image/jpeg',
-                         'application/vnd.ms-excel', 'text/plain', 'application/json',
-                         'application/application/vnd.openxmlformats-officedocument.spreadsheetml.sheet']
+        # headers_types = ['application/octet-stream', 'application/zip', 'image/png', 'image/jpeg',
+        #                  'application/vnd.ms-excel', 'text/plain', 'application/json', 'application/xml',
+        #                  'application/application/vnd.openxmlformats-officedocument.spreadsheetml.sheet']
         progress_indicator = None
         with closing(requests.get(url, stream=True)) as response:
-            if response.headers.get('Content-Type') not in headers_types:
-                _logger.error(f"当前文件 {filename} 不是可下载的文件流地址，请检查后再试")
-                return
+            # 暂时取消文件类型校验
+            # if response.headers.get('Content-Type') not in headers_types:
+            #     _logger.error(f"当前文件 {filename} 不是可下载的文件流地址，请检查后再试")
+            #     return
             if 'Content-Length' in response.headers:
                 content_size = int(response.headers.get('Content-Length'))  # 内容体总大小
             else:
@@ -600,7 +604,7 @@ class HostedBackend(Backend):
 
     @with_api_exceptions_handler
     @require_app
-    def create_model(self, name, desc, git_url, http_url, visibility):
+    def create_model(self, name, desc, git_url, http_url, visibility, source):
         """
         当前应用下创建模型
         :param visibility: 公有私有 public private 默认 private
@@ -609,6 +613,7 @@ class HostedBackend(Backend):
         :param auth_id: auth_id 默认空
         :param git_url: git地址 默认空
         :param http_url: http地址 默认空
+        :param source:模型来源 flow:画布 gitcode:git代码
         :return: List of Class `Model` Object
         """
         res = self._session.post(url=f'{self.api_address}/{self.app_id}/training/model/', json={"name": name,
@@ -616,14 +621,15 @@ class HostedBackend(Backend):
                                                                                                 "desc": desc,
                                                                                                 "git_url": git_url,
                                                                                                 "http_url": http_url,
-                                                                                                "visibility": visibility})
+                                                                                                "visibility": visibility,
+                                                                                                "source": source})
         if res.json()['message']:
             raise Exception(res.json()['message'])
         data = res.json()['data']
         self.set_model(data['id'])
         return Model(self, data['id'], data['name'], data['desc'], data['app_id'],
                      data['create_time'], data['create_user_id'], data['update_time'],
-                     data['update_user_id'])
+                     data['update_user_id'], data['source'])
 
     @with_api_exceptions_handler
     @require_app
@@ -639,7 +645,7 @@ class HostedBackend(Backend):
         dict = res.json()['data']
         return Model(self, dict['id'], dict['name'], dict['desc'], dict['app_id'],
                      dict['create_time'], dict['create_user_id'], dict['update_time'],
-                     dict['update_user_id'])
+                     dict['update_user_id'], dict['source'])
 
     @with_api_exceptions_handler
     @require_app
@@ -658,7 +664,7 @@ class HostedBackend(Backend):
         data = res.json()['data']
         return Model(self, data['id'], data['name'], data['desc'], data['app_id'],
                      data['create_time'], data['create_user_id'], data['update_time'],
-                     data['update_user_id'])
+                     data['update_user_id'], data['source'])
 
     @with_api_exceptions_handler
     @require_app
@@ -691,12 +697,12 @@ class HostedBackend(Backend):
 
     @with_api_exceptions_handler
     @require_model
-    def list_model_versions(self):
+    def list_model_versions(self, page, pagesize):
         """
         根据模型id，模型版本查询
         :return:
         """
-        res = self._session.get(url=f'{self.api_address}/{self.model_id}/training/model-repo/')
+        res = self._session.get(url=f'{self.api_address}/{self.model_id}/training/model-repo/?page={page}&pagesize={pagesize}')
         if res.json()['message']:
             raise Exception(res.json()['message'])
         dict = res.json()['data']['data']
@@ -793,12 +799,13 @@ class HostedBackend(Backend):
 
     @with_api_exceptions_handler
     @require_model
-    def register_model_version(self, desc, artifacts, mode):
+    def register_model_version(self, desc, artifacts, mode, json_data=None):
         """
         注册自定义模型
         :param desc:  模型版本说明
         :param artifacts:  上传文件路径
         :param mode:  模型模式
+        :param json_data: 模型版本其他信息
         :return:
         """
         if mode == ModelRegisterMode.DOCKER.value:
@@ -807,7 +814,7 @@ class HostedBackend(Backend):
         if mode == ModelRegisterMode.PYFUNC.value:
             res = self._session.post(
                 url=f'{self.api_address}/{self.model_id}/deploy/model/',
-                json={'desc': desc, 'mode': mode},
+                json={'desc': desc, 'mode': mode, 'json_data': json_data},
             )
             if res.json()["message"]:
                 raise Exception(res.json()["message"])
@@ -1447,10 +1454,10 @@ class HostedBackend(Backend):
             raise NotADirectory(destination_dir)
         client_ip = self._get_ip()
         try:
-            if DataSource.MAMMUT.value == datasource:
+            if DataSource.MAMMUT.value == datasource or DataSource.WTHINGS.value == datasource:
                 res = self._session.post(
                     url=f'{self.api_address}/{self.app_id}/data/dataset/netease/data/sdk/{dataset_id}',
-                    json={"query": query}, headers={"client-ip": client_ip})
+                    json={"query": query, "datasource": datasource}, headers={"client-ip": client_ip})
                 if res.json()["message"]:
                     return res.json()["message"]
                 path = res.json()['data']
